package ro.ieval.unical;

import android.app.ActionBar;
import android.app.Fragment;
import android.app.FragmentTransaction;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.*;

import java.text.SimpleDateFormat;
import java.util.Date;

public final class TrivialFragment extends Fragment {
	private static class OnItemSelectedListener implements android.widget.AdapterView.OnItemSelectedListener{
		private final View repeatCount;
		private final View repeatUntil;

		public OnItemSelectedListener(final View repeatCount, final View repeatUntil) {
			this.repeatCount=repeatCount;
			this.repeatUntil=repeatUntil;
		}

		@Override
		public void onItemSelected(final AdapterView<?> whatever, final View ignored, final int pos, final long id) {
			switch(pos){
			case 0:
				repeatCount.setVisibility(View.GONE);
				repeatUntil.setVisibility(View.GONE);
				break;
			case 1:
				repeatCount.setVisibility(View.GONE);
				repeatUntil.setVisibility(View.VISIBLE);
				break;
			case 2:
				repeatCount.setVisibility(View.VISIBLE);
				repeatUntil.setVisibility(View.GONE);
				break;
			default:
			}
        }

		@Override public void onNothingSelected(final AdapterView<?> arg0) { /* do nothing */	}
	}

	private static class OnCheckedChangeListener implements android.widget.CompoundButton.OnCheckedChangeListener{
		private final LinearLayout layout;
		private final View root;
		public OnCheckedChangeListener(final LinearLayout layout, final View root){
			this.layout=layout;
			this.root=root;
		}

		@Override
		public void onCheckedChanged(final CompoundButton buttonView, final boolean isChecked) {
			if(isChecked) {
				Utils.setEnabledRecursively(layout, true);
				final Spinner repeatType = (Spinner) root.findViewById(R.id.repeat_type);
				repeatType.setOnItemSelectedListener(new OnItemSelectedListener(root.findViewById(R.id.repeat_count),root.findViewById(R.id.repeat_until)));
			}else {
				Utils.setEnabledRecursively(layout, false);
			}
		}
	}

    public static final String ARGUMENT_EVENT = "Event";
	public static final String ARGUMENT_LAYOUT = "layout";
    private Event ev;

	@Override
    public View onCreateView(final LayoutInflater inflater, final ViewGroup container, final Bundle savedInstanceState) {
		final View view=inflater.inflate(getArguments().getInt(ARGUMENT_LAYOUT), container, false);

        ev=getArguments().getParcelable(ARGUMENT_EVENT);
        switch (getArguments().getInt(ARGUMENT_LAYOUT)) {
            case R.layout.add_event_basic_tab:
				final LinearLayout layout = (LinearLayout) view.findViewById(R.id.repeat_layout);
				final Switch repeatSwitch = (Switch) view.findViewById(R.id.repeat_switch);
				Utils.setEnabledRecursively(layout, false);
			
				repeatSwitch.setOnCheckedChangeListener(new OnCheckedChangeListener(layout, view));

                EditText title = (EditText) view.findViewById(R.id.eventtitle);
                title.setText(ev.title);

                TextView tstart = (TextView) view.findViewById(R.id.time_start);
                TextView tend = (TextView) view.findViewById(R.id.time_end);
                SimpleDateFormat sf=new SimpleDateFormat("HH:mm");
                Date d=new Date(ev.dtstart);
                tstart.setText(sf.format(d).toString());
                d.setTime(ev.dtend);
                tend.setText(sf.format(d).toString());

                SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd");
                TextView dstart = (TextView)view.findViewById(R.id.date_start);
                TextView dend = (TextView)view.findViewById(R.id.date_end);
                d.setTime(ev.dtstart);
                dstart.setText(sd.format(d).toString());
                d.setTime(ev.dtend);
                dend.setText(sd.format(d).toString());
                break;
            case R.layout.add_event_details_tab:
                EditText description = (EditText) view.findViewById(R.id.description);
                description.setText(ev.description);
                break;
            case R.layout.add_event_other_tab:
                break;
        }
		return view;
	}
}
